# FILE: oc.tcl
#
#	OOMMF core
#
# Last modified on: $Date: 2000/02/23 21:33:15 $
# Last modified by: $Author: dgp $
#
# When this version of the Oc extension is selected by the 'package require'
# command, this file is sourced.

# Verify minimum Tcl/Tk support
if {[catch {package require Tcl 8}]} {
    package require Tcl 7.5
}

proc Oc_CheckTclIndex {pkg} {
    if {[llength [info commands Oc_DirectPathname]]} {
        # Cosmetic fix, if it's available
        set index [Oc_DirectPathname \
            [file join [file dirname [info script]] tclIndex]]
    } else {
        set index [file join [file dirname [info script]] tclIndex]
    }
    if {![file isfile $index] || ![file readable $index]} {
        set msg "\nNo index found for $pkg\n\tMissing or unreadable\
                file: $index\n\n"
        if {[file exists [file join [file dirname [info script]] \
                makerules.tcl]]} {
            append msg "Run pimake in [file dirname $index]\nto construct\
                    the missing index file.\n"
        } else {
            append msg "This probably means $pkg was installed incorrectly.\n"
        }
        return -code error $msg
    }
}

Oc_CheckTclIndex Oc

# CVS 
package provide Oc 1.0.1.3

# Set up for autoloading of Oc extension commands
set oc(library) [file dirname [info script]]
if { [lsearch -exact $auto_path $oc(library)] == -1 } {
    lappend auto_path $oc(library)
}

# Gain access to other extensions in the OOMMF project
if { [lsearch -exact $auto_path [file dirname $oc(library)]] == -1 } {
    lappend auto_path [file dirname $oc(library)]
}

# Patch any bugs and missing features in old versions of Tcl
regsub {[.]} [package provide Tcl] {} _
set _ [file join [file dirname [info script]] bug$_.tcl]
if {[file readable $_]} {
    source $_
} else {
    source [file join [file dirname [info script]] bug.tcl]
}

# Bring in OOMMF customizations
source [file join [file dirname [info script]] custom.tcl]

# Initialize the Oc_Main class
Oc_Main Initialize

# Process -console argument
set i 0
while {[string length [set arg [lindex $argv $i]]]} {
    switch -exact -- $arg {
        -console {
            set _ [file join [file dirname [info script]] console.tcl]
            if {[file readable $_]} {
                source $_
            } else {
                error "Can't create console: File not readable: $_"
            }
            set argv [lreplace $argv $i $i]
        }
        default {
            incr i
        }
    }
}

# Load in any local modifications
set _ [file join [file dirname [info script]] local oc.tcl]
if {[file isfile $_] && [file readable $_]} {
    uplevel #0 source [list $_]
}
unset arg i _

